@@ -18,7 +18,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-import ansiblelint.utils
 import os
 from ansiblelint import AnsibleLintRule
 
@@ -30,10 +29,10 @@ class CommandsInsteadOfModulesRule(AnsibleLintRule):
                   'is generally a bad idea'
     tags = ['resources']
 
-    _commands = ['command', 'shell', 'raw']
+    _commands = ['command', 'shell']
     _modules = {'git': 'git', 'hg': 'hg', 'curl': 'get_url', 'wget': 'get_url',
-                'svn': 'subversion', 'cp': 'copy', 'service': 'service',
-                'mount': 'mount', 'rpm': 'yum', 'yum': 'yum', 'apt-get': 'apt-get',
+                'svn': 'subversion', 'service': 'service', 'mount': 'mount',
+                'rpm': 'yum', 'yum': 'yum', 'apt-get': 'apt-get',
                 'unzip': 'unarchive', 'tar': 'unarchive'}
 
     def matchtask(self, file, task):
