@@ -22,8 +22,14 @@ import os
 import glob
 import imp
 import ansible.utils
-import shlex
 from ansible.playbook.task import Task
+import ansible.constants as C
+from ansible.module_utils.splitter import split_args
+import yaml
+from yaml.composer import Composer
+from yaml.constructor import Constructor
+
+LINE_NUMBER_KEY = '__line__'
 
 
 def load_plugins(directory):
@@ -82,7 +88,14 @@ def find_children(playbook):
     items = _playbook_items(pb_data)
     for item in items:
         for child in play_children(basedir, item, playbook[1]):
-            path = shlex.split(child['path'])[0]  # strip tags=smsng
+            if "$" in child['path'] or "{{" in child['path']:
+                continue
+            valid_tokens = list()
+            for token in split_args(child['path']):
+                if '=' in token:
+                    break
+                valid_tokens.append(token)
+            path = ' '.join(valid_tokens)
             results.append({
                 'path': ansible.utils.path_dwim(basedir, path),
                 'type': child['type']
@@ -128,26 +141,42 @@ def _roles_children(basedir, k, v, parent_type):
 
 
 def _rolepath(basedir, role):
-    if os.path.isabs(role):
-        return role
-    # if included from a playbook
-    pbrolepath = ansible.utils.path_dwim(basedir, os.path.join('roles', role))
-    if os.path.exists(pbrolepath):
-        return pbrolepath
-    # if included from roles/meta/main.yml
-    gpdir = os.path.normpath(os.path.join(basedir, '..', '..'))
-    if os.path.basename(gpdir) == 'roles':
-        rolepath = os.path.join(gpdir, role)
-        return rolepath
-    return basedir
+    role_path = None
+
+    possible_paths = [
+        # if included from a playbook
+        ansible.utils.path_dwim(basedir, os.path.join('roles', role)),
+        ansible.utils.path_dwim(basedir, role),
+        # if included from roles/[role]/meta/main.yml
+        ansible.utils.path_dwim(
+            basedir, os.path.join('..', '..', '..', 'roles', role)
+        ),
+        ansible.utils.path_dwim(basedir,
+                                os.path.join('..', '..', role))
+    ]
+
+    if C.DEFAULT_ROLES_PATH:
+        search_locations = C.DEFAULT_ROLES_PATH.split(os.pathsep)
+        for loc in search_locations:
+            loc = os.path.expanduser(loc)
+            possible_paths.append(ansible.utils.path_dwim(loc, role))
+
+    for path_option in possible_paths:
+        if os.path.isdir(path_option):
+            role_path = path_option
+            break
+
+    return role_path
 
 
 def _look_for_role_files(basedir, role):
     results = []
     for th in ['tasks', 'handlers', 'meta']:
-        thpath = os.path.join(_rolepath(basedir, role), th, 'main.yml')
-        if os.path.exists(thpath):
-            results.append({'path': thpath, 'type': th})
+        role_path = _rolepath(basedir, role)
+        if role_path:
+            thpath = os.path.join(role_path, th, 'main.yml')
+            if os.path.exists(thpath):
+                results.append({'path': thpath, 'type': th})
     return results
 
 
@@ -180,7 +209,7 @@ def normalize_task(task):
             else:
                 result[k] = v
         else:
-            if isinstance(v, str):
+            if isinstance(v, basestring):
                 v = _kv_to_dict(k + ' ' + v)
             elif not v:
                 v = dict(module=k)
@@ -188,8 +217,14 @@ def normalize_task(task):
                 if isinstance(v, dict):
                     v.update(dict(module=k))
                 else:
-                    # Should not get here!
-                    assert False
+                    if k == '__line__':
+                        # Keep the line number stored
+                        result[k] = v
+                        continue
+
+                    else:
+                        # Should not get here!
+                        assert False
             v['module_arguments'] = v.get('module_arguments', list())
             result['action'] = v
     return result
@@ -217,3 +252,27 @@ def get_action_tasks(yaml, file):
                     tasks.extend(block_tasks)
     return [normalize_task(task) for task in tasks
             if 'include' not in task.keys()]
+
+
+def parse_yaml_linenumbers(data):
+    """Parses yaml as ansible.utils.parse_yaml but with linenumbers.
+
+    The line numbers are stored in each node's LINE_NUMBER_KEY key"""
+    loader = yaml.Loader(data)
+
+    def compose_node(parent, index):
+        # the line number where the previous token has ended (plus empty lines)
+        line = loader.line
+        node = Composer.compose_node(loader, parent, index)
+        node.__line__ = line + 1
+        return node
+
+    def construct_mapping(node, deep=False):
+        mapping = Constructor.construct_mapping(loader, node, deep=deep)
+        mapping[LINE_NUMBER_KEY] = node.__line__
+        return mapping
+
+    loader.compose_node = compose_node
+    loader.construct_mapping = construct_mapping
+    data = loader.get_single_data()
+    return data
